@@ -26,8 +26,13 @@ http://www.blockattack.net
 #include "common.h"
 #include "ReadKeyboard.h"
 
-static void NFont_Write(SDL_Renderer* target, int x, int y, const std::string& text) {
-	globalData.nf_standard_blue_font.draw(target, x, y, "%s", text.c_str());
+static void setButtonFont(const sago::SagoDataHolder* holder, sago::SagoTextField& field, const char* text) {
+	field.SetHolder(holder);
+	field.SetFont("freeserif");
+	field.SetColor({255,255,255,255});
+	field.SetFontSize(24);
+	field.SetOutline(1, {0,0,0,255});
+	field.SetText(text);
 }
 
 static void DrawRect(SDL_Renderer* target, int topx, int topy, int height, int width, const std::string& name) {
@@ -64,7 +69,7 @@ static void DrawRectWhite(SDL_Renderer* target, int topx, int topy, int height,
 	DrawRect(target, topx, topy, height, width, name);
 }
 
-static void DrawRectYellow(SDL_Renderer* target, int topx, int topy, int height, int width) {
+void DrawRectYellow(SDL_Renderer* target, int topx, int topy, int height, int width) {
 	std::string name = "ui_rect_yellow_";
 	DrawRect(target, topx, topy, height, width, name);
 }
@@ -83,6 +88,12 @@ DialogBox::DialogBox(int x, int y, const std::string& name, const std::string& h
 	this->x = x;
 	this->y = y;
 	SetName(name);
+	setButtonFont(&globalData.spriteHolder->GetDataHolder(), headerLabel, header.c_str());
+	setButtonFont(&globalData.spriteHolder->GetDataHolder(), enterLabel, _("Enter to accept"));
+	setButtonFont(&globalData.spriteHolder->GetDataHolder(), cancelLabel, _("Esc to cancel"));
+	sagoTextSetBlueFont(textField);
+	sagoTextSetBlueFont(cursorLabel);
+	cursorLabel.SetText("|");
 }
 
 
@@ -99,23 +110,27 @@ void DialogBox::Draw(SDL_Renderer* target) {
 	this->x = globalData.xsize/2-300;
 	this->y = globalData.ysize/2-100;
 	DrawRectYellow(target, x, y, 200, 600);
-	globalData.nf_button_font.draw(target, x+300, y+20, NFont::CENTER, "%s", header.c_str());
-	globalData.nf_button_font.draw(target, x+150, y+140, NFont::CENTER, _("Enter to accept"));
-	globalData.nf_button_font.draw(target, x+450, y+140, NFont::CENTER, _("Esc to cancel"));
+	headerLabel.Draw(target, x+300, y+20, sago::SagoTextField::Alignment::center);
+	enterLabel.Draw(target, x+150, y+140, sago::SagoTextField::Alignment::center);
+	cancelLabel.Draw(target, x+450, y+140, sago::SagoTextField::Alignment::center);
 	DrawRectWhite(target, x+26, y+64, 54, 600-2*26);
-	NFont_Write(target, x+40, y+76,rk->GetString());
+	textField.SetText(rk->GetString());
+	textField.Draw(target, x+40, y+76);
 	std::string strHolder = rk->GetString();
 	strHolder.erase((int)rk->CharsBeforeCursor());
 
 	if (((SDL_GetTicks()/600)%2)==1) {
-		NFont_Write(target, x+40+globalData.nf_standard_blue_font.getWidth( "%s", strHolder.c_str()),y+76,"|");
+		int width = 0;
+		textField.GetRenderedSize( strHolder.c_str(), &width);
+		width -= 2;
+		cursorLabel.Draw(target, x+40+width,y+76);
 	}
 }
 
 void DialogBox::ProcessInput(const SDL_Event& event, bool& processed) {
 	if (event.type == SDL_TEXTINPUT) {
 		if ((rk->ReadKey(event))&&(globalData.SoundEnabled)&&(!globalData.NoSound)) {
-			Mix_PlayChannel(1, globalData.typingChunk, 0);
+			Mix_PlayChannel(1, globalData.typingChunk.get(), 0);
 		}
 	}
 
@@ -130,7 +145,7 @@ void DialogBox::ProcessInput(const SDL_Event& event, bool& processed) {
 		}
 		else {
 			if ((rk->ReadKey(event))&&(globalData.SoundEnabled)&&(!globalData.NoSound)) {
-				Mix_PlayChannel(1, globalData.typingChunk, 0);
+				Mix_PlayChannel(1, globalData.typingChunk.get(), 0);
 			}
 		}
 	}
