@@ -1,7 +1,7 @@
 /*
 ===========================================================================
 blockattack - Block Attack - Rise of the Blocks
-Copyright (C) 2005-2012 Poul Sander
+Copyright (C) 2005-2018 Poul Sander
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see http://www.gnu.org/licenses/
 
 Source information and contacts persons can be found at
-http://blockattack.net
+https://blockattack.net
 ===========================================================================
 */
 
@@ -25,9 +25,6 @@ http://blockattack.net
 #include "utf8.h"
 #include <iostream>
 
-using std::string;
-using std::cerr;
-
 ReadKeyboard::ReadKeyboard(void) {
 	maxLength = 16;
 	position = text_string.begin();
@@ -40,9 +37,7 @@ int ReadKeyboard::CharsBeforeCursor() {
 	return std::distance(text_string.begin(), position);
 }
 
-ReadKeyboard::ReadKeyboard(const char* oldName) {
-	maxLength = 16;
-	text_string = oldName;
+ReadKeyboard::ReadKeyboard(const char* oldName) : maxLength(16), text_string(oldName) {
 	position = text_string.end();
 }
 
@@ -60,7 +55,7 @@ void ReadKeyboard::putchar(const std::string& thing) {
 
 void ReadKeyboard::removeChar() {
 	if (position < text_string.end()) {
-		string::iterator endChar= position;
+		std::string::iterator endChar= position;
 		utf8::advance(endChar, 1, text_string.end());
 		text_string.erase(position, endChar);
 	}
