@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see http://www.gnu.org/licenses/
 
 Source information and contacts persons can be found at
-http://www.blockattack.net
+https://blockattack.net
 ===========================================================================
 */
 
@@ -66,7 +66,7 @@ http://www.blockattack.net
 
 #include "highscore.h"      //Stores highscores
 #include "ReadKeyboard.h"   //Reads text from keyboard
-#include "stats.h"          //Saves general stats 
+#include "stats.h"          //Saves general stats
 #include "replayhandler.hpp"
 
 #include "common.h"
@@ -98,15 +98,15 @@ static void FsSearchParthMainAppend(std::vector<std::string>& paths) {
 
 static void PhysFsSetSearchPath(const vector<string>& paths, const string& savepath) {
 	for (const string& path : paths) {
-		PHYSFS_addToSearchPath(path.c_str(),1);
+		PHYSFS_mount(path.c_str(), "/", 0);
 	}
-	PHYSFS_addToSearchPath(savepath.c_str(), 1);
+	PHYSFS_mount(savepath.c_str(), "/", 0);
 	PHYSFS_setWriteDir(savepath.c_str());
 }
 
 
 static void PhysFsCreateFolders() {
-	PHYSFS_mkdir("screenshots");
+	//PHYSFS_mkdir("screenshots");
 	PHYSFS_mkdir("replays");
 	PHYSFS_mkdir("puzzles");
 }
@@ -132,6 +132,7 @@ static int InitImages(sago::SagoSpriteHolder& holder) {
 	bricks[6] = holder.GetSprite("block_grey");
 	bomb = holder.GetSprite("block_bomb");
 	backgroundImage = holder.GetSprite("background");
+	backgroundSixteenNineImage = holder.GetSprite("background_sixteen_nine");
 	globalData.bHighScore = holder.GetSprite("b_highscore");
 	globalData.bBack = holder.GetSprite("b_blank");
 	bForward = holder.GetSprite("b_forward");
@@ -247,11 +248,26 @@ sago::SagoDataHolder dataHolder;
 void ResetFullscreen() {
 	Mix_HaltMusic();  //We need to reload all data in case the screen type changes. Music must be stopped before unload.
 	if (globalData.bFullscreen) {
+		SDL_DisplayMode dm;
+		globalData.xsize = SIXTEEN_NINE_WIDTH;
+		globalData.ysize = SCREEN_HIGHT;
+		if (SDL_GetDesktopDisplayMode(0, &dm) == 0) {
+			globalData.xsize = globalData.ysize*dm.w/(double)dm.h;
+		}
 		SDL_SetWindowFullscreen(sdlWindow, SDL_WINDOW_FULLSCREEN_DESKTOP);
 	}
 	else {
+		globalData.xsize = FOUR_THREE_WIDTH;
+		globalData.ysize = SCREEN_HIGHT;
 		SDL_SetWindowFullscreen(sdlWindow, 0);
 	}
+	if (globalData.alwaysSixteenNine || globalData.xsize > SIXTEEN_NINE_WIDTH) {
+		globalData.xsize = SIXTEEN_NINE_WIDTH;
+	}
+	if (globalData.xsize < FOUR_THREE_WIDTH) {
+		globalData.xsize = FOUR_THREE_WIDTH;
+	}
+	SDL_RenderSetLogicalSize(globalData.screen, globalData.xsize, globalData.ysize);
 	dataHolder.invalidateAll(globalData.screen);
 	globalData.spriteHolder.reset(new sago::SagoSpriteHolder( dataHolder ) );
 	InitImages(*(globalData.spriteHolder.get()) );
@@ -262,14 +278,12 @@ static bool logicalRenderer = false;
 
 void DrawBackground(SDL_Renderer* target) {
 	SDL_RenderClear(target);
-	if (logicalRenderer) {
-		globalData.xsize = 1024;
-		globalData.ysize = 768;
+	if ( (double)globalData.xsize/globalData.ysize > 1.5) {
+		backgroundSixteenNineImage.DrawScaled(target, SDL_GetTicks(), 0, 0, globalData.xsize, globalData.ysize);
 	}
 	else {
-		SDL_GetWindowSize(sdlWindow, &globalData.xsize, &globalData.ysize);
+		backgroundImage.DrawScaled(target, SDL_GetTicks(), 0, 0, globalData.xsize, globalData.ysize);
 	}
-	backgroundImage.DrawScaled(target, SDL_GetTicks(), 0, 0, globalData.xsize, globalData.ysize);
 }
 
 /**
@@ -309,8 +323,16 @@ static ExplosionManager theExplosionManager;
 #include "BlockGameSdl.inc"
 #include "sago/SagoMisc.hpp"
 #include "ReplayPlayer.hpp"
+#include "sago/platform_folders.h"
 
-
+std::string pathToScreenShots() {
+	Config::getInstance()->setDefault("screenshot_dir", _("Block Attack - Rise of the Blocks"));
+	std::string screenshot_dir = Config::getInstance()->getString("screenshot_dir");
+	if (OsPathIsRelative(screenshot_dir)) {
+		return sago::getPicturesFolder() + "/" + screenshot_dir;
+	}
+	return screenshot_dir;
+}
 
 //writeScreenShot saves the screen as a bmp file, it uses the time to get a unique filename
 void writeScreenShot() {
@@ -318,9 +340,26 @@ void writeScreenShot() {
 		cout << "Saving screenshot" << "\n";
 	}
 	int rightNow = (int)time(nullptr);
-	string buf = getPathToSaveFiles() + "/screenshots/screenshot"+std::to_string(rightNow)+".bmp";
-	SDL_Surface* sreenshotSurface = SDL_CreateRGBSurface(0, 1024, 768, 32, 0x00ff0000, 0x0000ff00, 0x000000ff, 0xff000000);
-	SDL_RenderReadPixels(globalData.screen, NULL, SDL_PIXELFORMAT_ARGB8888, sreenshotSurface->pixels, sreenshotSurface->pitch);
+	SDL_Surface* infoSurface = SDL_GetWindowSurface(sdlWindow);
+	if (!infoSurface) {
+		std::cerr << "Could not get infoSurface. No screenshot written. Be aware that the screenshot feature only works with software render\n";
+		return;
+	}
+	std::vector<char> pixels(infoSurface->w * infoSurface->h * infoSurface->format->BytesPerPixel);
+	int errorCode = SDL_RenderReadPixels(globalData.screen, &infoSurface->clip_rect, infoSurface->format->format, static_cast<void*>(pixels.data()), infoSurface->w * infoSurface->format->BytesPerPixel);
+	if (errorCode) {
+		SDL_FreeSurface(infoSurface);
+		std::cerr << "Could not do SDL_RenderReadPixels. Error code: " << errorCode << ". No screenshot written\n";
+		return;
+	}
+	SDL_Surface* sreenshotSurface = SDL_CreateRGBSurfaceFrom(static_cast<void*>(pixels.data()), infoSurface->w, infoSurface->h, infoSurface->format->BitsPerPixel, infoSurface->w * infoSurface->format->BytesPerPixel, infoSurface->format->Rmask, infoSurface->format->Gmask, infoSurface->format->Bmask, infoSurface->format->Amask);
+	SDL_FreeSurface(infoSurface);
+	if (!sreenshotSurface) {
+		std::cerr << "Could not get sreenshotSurface. No screenshot written\n";
+		return;
+	}
+	OsCreateFolder(pathToScreenShots());
+	std::string buf = pathToScreenShots() + "/screenshot"+std::to_string(rightNow)+".bmp";
 	SDL_SaveBMP(sreenshotSurface, buf.c_str());
 	SDL_FreeSurface(sreenshotSurface);
 	if (!globalData.NoSound) {
@@ -674,11 +713,15 @@ static bool registerTTHighscorePlayer1 = false;
 static bool registerTTHighscorePlayer2 = false;
 static bool saveReplay = false;
 
-static void StartSinglePlayerEndless() {
+/**
+ * startSpeed is a value from 0 to 4
+ * */
+static void StartSinglePlayerEndless(int startSpeed) {
 	//1 player - endless
 	BlockGameStartInfo startInfo;
 	startInfo.ticks = SDL_GetTicks();
 	startInfo.startBlocks = startInfo.ticks;
+	startInfo.gameSpeed = startSpeed;
 	player1->NewGame(startInfo);
 	twoPlayers =false;
 	BlockGameAction a;
@@ -722,7 +765,6 @@ static int StartSinglePlayerPuzzle() {
 	a.action = BlockGameAction::Action::SET_GAME_OVER;
 	a.tick = startInfo.ticks;
 	player2->DoAction(a);
-	//vsMode = true;
 	player1->name = globalData.player1name;
 	player2->name = globalData.player2name;
 	return 0;
@@ -778,15 +820,14 @@ static void StartTwoPlayerVs() {
 	startInfo2.handicap = player2handicap;
 	player1->NewGame(startInfo);
 	player2->NewGame(startInfo2);
-	//vsMode = true;
 	twoPlayers = true;
 	player1->name = globalData.player1name;
 	player2->name = globalData.player2name;
 }
 
 static void MoveBlockGameSdls( BlockGameSdl& game1, BlockGameSdl& game2 ) {
-	game1.SetTopXY(50, globalData.ysize/2-284);
-	game2.SetTopXY(globalData.xsize-500, globalData.ysize/2-284);
+	game1.SetTopXY(globalData.xsize/2-440, globalData.ysize/2-284);
+	game2.SetTopXY(globalData.xsize/2+40, globalData.ysize/2-284);
 }
 
 struct globalConfig {
@@ -821,6 +862,7 @@ static void ParseArguments(int argc, char* argv[], globalConfig& conf) {
 	("verbose-game-controller", "Enables verbose messages regarding controllers")
 	("print-search-path", "Prints the search path and quits")
 	("no-auto-scale", "Do not automatically auto scale")
+	("always-sixteen-nine", "Use 16:9 format even in Window mode")
 	("puzzle-level-file", boost::program_options::value<string>(), "Sets the default puzzle file to load")
 	("puzzle-single-level", boost::program_options::value<int>(), "Start the specific puzzle level directly")
 #ifdef REPLAY_IMPLEMENTED
@@ -912,6 +954,9 @@ static void ParseArguments(int argc, char* argv[], globalConfig& conf) {
 	if (vm.count("no-auto-scale")) {
 		conf.autoScale = false;
 	}
+	if (vm.count("always-sixteen-nine")) {
+		globalData.alwaysSixteenNine = true;
+	}
 	if (vm.count("puzzle-level-file")) {
 		conf.puzzleName = vm["puzzle-level-file"].as<string>();
 	}
@@ -940,13 +985,16 @@ int main(int argc, char* argv[]) {
 		ParseArguments(argc, argv, config);
 		OsCreateSaveFolder();
 		PhysFsSetSearchPath(config.search_paths, config.savepath);
-		//Os create folders must be after the paramters because they can change the home folder
+		//Os create folders must be after the parameters because they can change the home folder
 		PhysFsCreateFolders();
+		bool gameShutdownProperly = true;
+		if (sago::FileExists("gameRunning")) {
+			gameShutdownProperly = false;
+		}
+		sago::WriteFileContent("gameRunning", "Started");
 		globalData.SoundEnabled = true;
 		globalData.MusicEnabled = true;
 		twoPlayers = false; //true if two players splitscreen
-		globalData.theTopScoresEndless = Highscore("endless");
-		globalData.theTopScoresTimeTrial = Highscore("timetrial");
 		drawBalls = true;
 		puzzleLoaded = false;
 		theBallManager = BallManager();
@@ -998,7 +1046,7 @@ int main(int argc, char* argv[]) {
 		keySettings[player2keys].change = SDLK_LCTRL;
 		keySettings[player2keys].push = SDLK_LSHIFT;
 
-		globalData.player1name = _("Player 1");
+		globalData.player1name = defaultPlayerName();
 		globalData.player2name = _("Player 2");
 
 		Config* configSettings = Config::getInstance();
@@ -1071,6 +1119,13 @@ int main(int argc, char* argv[]) {
 				cout << "Unable to load options file, using default values" << "\n";
 			}
 		}
+		if (configSettings->getInt("always-software")) {
+			config.softwareRenderer = true;
+		}
+		if (!gameShutdownProperly) {
+			std::cerr << "Game not shotdown. Using software renderer.\n";
+			config.softwareRenderer = true;
+		}
 
 		// "Block Attack - Rise of the Blocks"
 		SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "2");
@@ -1079,10 +1134,15 @@ int main(int argc, char* argv[]) {
 		if (config.allowResize) {
 			createWindowParams |= SDL_WINDOW_RESIZABLE;
 		}
+		globalData.xsize = FOUR_THREE_WIDTH;
+		if (globalData.alwaysSixteenNine) {
+			globalData.xsize = SIXTEEN_NINE_WIDTH;
+		}
+		globalData.ysize = SCREEN_HIGHT;
 		sdlWindow = SDL_CreateWindow("Block Attack - Rise of the Blocks " VERSION_NUMBER,
 		                             SDL_WINDOWPOS_UNDEFINED,
 		                             SDL_WINDOWPOS_UNDEFINED,
-		                             (screenHeight)*4/3, screenHeight,
+		                             (screenHeight)*globalData.xsize/globalData.ysize, screenHeight,
 		                             createWindowParams );
 		dieOnNullptr(sdlWindow, "Unable to create window");
 		int rendererFlags = 0;
@@ -1092,7 +1152,7 @@ int main(int argc, char* argv[]) {
 		SDL_Renderer* renderer = SDL_CreateRenderer(sdlWindow, -1, rendererFlags);
 		dieOnNullptr(renderer, "Unable to create render");
 		if (config.autoScale) {
-			SDL_RenderSetLogicalSize(renderer, 1024, 768);
+			SDL_RenderSetLogicalSize(renderer, globalData.xsize, globalData.ysize);
 			logicalRenderer = true;
 		}
 		if (globalData.verboseLevel) {
@@ -1108,8 +1168,8 @@ int main(int argc, char* argv[]) {
 			cout << "Images loaded" << "\n";
 		}
 
-		BlockGameSdl theGame = BlockGameSdl(50, 100, &globalData.spriteHolder->GetDataHolder());            //creates game objects
-		BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize-500, 100, &globalData.spriteHolder->GetDataHolder());
+		BlockGameSdl theGame = BlockGameSdl(globalData.xsize/2-426, 100, &globalData.spriteHolder->GetDataHolder());            //creates game objects
+		BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize/2+40, 100, &globalData.spriteHolder->GetDataHolder());
 		player1 = &theGame;
 		player2 = &theGame2;
 
@@ -1143,6 +1203,9 @@ int main(int argc, char* argv[]) {
 			RunGameState(rp);
 		}
 		else {
+			if (!gameShutdownProperly) {
+				SafeModeMenu();
+			}
 			//game loop
 			MainMenu();
 		}
@@ -1171,7 +1234,7 @@ int main(int argc, char* argv[]) {
 
 			configSettings->setString("player1name", globalData.player1name);
 			configSettings->setString("player2name", globalData.player2name);
-			{
+			if (!globalData.bFullscreen){
 				//Store physical height of window
 				int height = 0;
 				SDL_GetWindowSize(sdlWindow, nullptr, &height);
@@ -1199,22 +1262,22 @@ int main(int argc, char* argv[]) {
 	catch (exception& e) {
 		sago::SagoFatalError(e.what());
 	}
+	PHYSFS_delete("gameRunning");
 	//Close file system Apstraction layer!
 	PHYSFS_deinit();
 	return 0;
 }
 
 int runGame(Gametype gametype, int level) {
-	globalData.theTopScoresEndless = Highscore("endless");
-	globalData.theTopScoresTimeTrial = Highscore("timetrial");
+	Highscore theTopScoresTimeTrial = Highscore("timetrial", 0.5);
 	drawBalls = true;
 	puzzleLoaded = false;
 	bool bNearDeath = false;  //Play music faster or louder while tru
 
 	theBallManager = BallManager();
 	theExplosionManager = ExplosionManager();
-	BlockGameSdl theGame = BlockGameSdl(50, 100, &globalData.spriteHolder->GetDataHolder());  //creates game objects
-	BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize-500, 100, &globalData.spriteHolder->GetDataHolder());
+	BlockGameSdl theGame = BlockGameSdl(globalData.xsize/2-426, 100, &globalData.spriteHolder->GetDataHolder());  //creates game objects
+	BlockGameSdl theGame2 = BlockGameSdl(globalData.xsize/2+4, 100, &globalData.spriteHolder->GetDataHolder());
 	player1 = &theGame;
 	player2 = &theGame2;
 	theGame.DoPaintJob();  //Makes sure what there is something to paint
@@ -1304,7 +1367,7 @@ int runGame(Gametype gametype, int level) {
 				break;
 			case Gametype::SinglePlayerEndless:
 			default:
-				StartSinglePlayerEndless();
+				StartSinglePlayerEndless(level);
 			};
 			mustsetupgame = false;
 			DrawBackground(globalData.screen);
@@ -1726,15 +1789,16 @@ int runGame(Gametype gametype, int level) {
 
 		if (theGame.isGameOver() && registerTTHighscorePlayer1) {
 			registerTTHighscorePlayer1 = false;
-			globalData.theTopScoresTimeTrial.addScore(theGame.name, theGame.GetScore());
+			theTopScoresTimeTrial.addScore(theGame.name, theGame.GetScore());
 		}
 		if (theGame2.isGameOver() && registerTTHighscorePlayer2) {
 			registerTTHighscorePlayer2 = false;
-			globalData.theTopScoresTimeTrial.addScore(theGame2.name, theGame2.GetScore());
+			theTopScoresTimeTrial.addScore(theGame2.name, theGame2.GetScore());
 		}
 		if (theGame.isGameOver() && registerEndlessHighscore) {
+			Highscore theTopScoresEndless = Highscore("endless", theGame.GetBaseSpeed());
 			registerEndlessHighscore = false;
-			globalData.theTopScoresEndless.addScore(theGame.name, theGame.GetScore());
+			theTopScoresEndless.addScore(theGame.name, theGame.GetScore());
 			theGame.EndlessHighscoreEvent();
 		}
 #ifdef REPLAY_IMPLEMENTED
