@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see http://www.gnu.org/licenses/
 
 Source information and contacts persons can be found at
-http://blockattack.net
+https://blockattack.net
 ===========================================================================
 */
 
@@ -32,6 +32,12 @@ std::string getPathToSaveFiles();
 std::string getMyDocumentsPath();
 #endif
 
+std::string defaultPlayerName();
+
 void setPathToSaveFiles(const std::string& path);
 
 void OsCreateSaveFolder();
+
+bool OsPathIsRelative(const std::string& path);
+
+void OsCreateFolder(const std::string& path);
