@@ -30,10 +30,10 @@ SOFTWARE.
 
 namespace sago {
 
-class SagoSpriteHolder {
+class SagoSpriteHolder final {
 public:
-	SagoSpriteHolder(const SagoDataHolder &texHolder);
-	virtual ~SagoSpriteHolder();
+	explicit SagoSpriteHolder(const SagoDataHolder &texHolder);
+	~SagoSpriteHolder();
 	void ReadSprites();
 	const sago::SagoSprite& GetSprite(const std::string &spritename) const;
 	const SagoDataHolder& GetDataHolder() const;
