@@ -17,10 +17,18 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see http://www.gnu.org/licenses/
 
 Source information and contacts persons can be found at
-http://www.blockattack.net
+https://blockattack.net
 ===========================================================================
 */
 
+
+/*
+ *Files will be saved in:
+ * HOME/.local/share/"+GAMENAME (unix)
+ *or DOCUMENTS/My Games/GAMENAME (Windows)
+ */
+#define GAMENAME "blockattack"
+
 #ifndef VERSION_NUMBER
-#define VERSION_NUMBER "2.3.0"
+#define VERSION_NUMBER "2.5.0"
 #endif
